from md_translate.arguments_processor import settings
from md_translate.exceptions import NoApiKeyFileError
from md_translate.files_worker import FilesWorker


class App:
    def __init__(self):
        self.settings = settings
        self.__validate_setup()

    def __validate_setup(self):
        try:
            self.settings.validate_arguments()
        except NoApiKeyFileError as err:
            print(err.get_message())
            exit(1)

    def process(self):
        FilesWorker(self.settings.path).process()


def main():
    try:
        App().process()
        exit(0)
    except Exception as err:
        print(err)
        exit(1)


if __name__ == "__main__":
    main()



import pathlib

from md_translate.exceptions import DirectoryNotFoundException
from md_translate.file_translator import FileTranslator


class FilesWorker:
    def __init__(self, folder_to_process):
        self.__folder_to_process: pathlib.Path = pathlib.Path(folder_to_process)
        self.__validate_folder()
        self.md_files_list: list = self.__get_md_files_list()

    def __validate_folder(self):
        if not self.__folder_to_process.exists():
            raise DirectoryNotFoundException('No such folder: {}!'.format(self.__folder_to_process))
        if not self.__folder_to_process.is_dir():
            raise NotADirectoryError('With selected path provided a file, not a folder!')

    def __get_md_files_list(self) -> list:
        md_files_list = []
        for link in self.__folder_to_process.iterdir():
            if link.suffix == '.md':
                md_files_list.append(link.name)
        if len(md_files_list) == 0:
            raise FileNotFoundError('There are no MD files found with provided path!')
        return md_files_list

    def process(self):
        for file_name in self.md_files_list:
            md_file_abs_path = self.__folder_to_process.joinpath(file_name)
            with FileTranslator(md_file_abs_path) as processing_file:
                processing_file.translate()
            print('Processed: {file_name}'.format(file_name=file_name))
